print("import: '_cscore'")
import _cscore

print("import: 'cscore'")
import cscore

print("import: 'cscore.grip'")
import cscore.grip

print("import: 'cscore.imagewriter'")
import cscore.imagewriter

